@@ -7,16 +7,16 @@ use Statistics::Lite qw(statshash);
 use HTML::Feature::Result;
 
 sub run {
-    my $self = shift;
-    my $c    = shift;
+    my $self     = shift;
+    my $c        = shift;
     my $html_ref = shift;
-    $self->_tag_cleaning($c, $html_ref);
-    return $self->_score($c, $html_ref);
+    $self->_tag_cleaning( $c, $html_ref );
+    return $self->_score( $c, $html_ref );
 }
 
 sub _tag_cleaning {
-    my $self = shift;
-    my $c    = shift;
+    my $self     = shift;
+    my $c        = shift;
     my $html_ref = shift;
     return unless $html_ref && $$html_ref;
 
@@ -38,16 +38,16 @@ sub _tag_cleaning {
 }
 
 sub _score {
-    my $self = shift;
-    my $c    = shift;
+    my $self     = shift;
+    my $c        = shift;
     my $html_ref = shift;
-    my $root = HTML::TreeBuilder->new_from_content( $$html_ref );
-    my $result = HTML::Feature::Result->new;
+    my $root     = HTML::TreeBuilder->new_from_content($$html_ref);
+    my $result   = HTML::Feature::Result->new;
 
     my $data;
 
     if ( my $title = $root->find("title") ) {
-        $result->title($title->as_text);
+        $result->title( $title->as_text );
     }
 
     if ( my $desc = $root->look_down( _tag => 'meta', name => 'description' ) )
@@ -61,7 +61,6 @@ sub _score {
     my @ratio;
     my @depth;
     my @order;
-    my $CACHE = $c->{cache} ? {} : undef;
     for my $node ( $root->look_down( "_tag", qr/body|center|td|div/i ) ) {
         my $html_length = bytes::length( $node->as_HTML );
         my $text        = $node->as_text;
@@ -81,13 +80,13 @@ sub _score {
         my $a_length      = 0;
         my $option_count  = 0;
         my $option_length = 0;
-        my %node_hash = (
-            text => '',
-            a_length => 0,
+        my %node_hash     = (
+            text                => '',
+            a_length            => 0,
             short_string_length => 0
         );
 
-        $self->_walk_tree( $node, \%node_hash, $CACHE );
+        $self->_walk_tree( $node, \%node_hash );
 
         $node_hash{a_length}            ||= 0;
         $node_hash{option_length}       ||= 0;
@@ -113,7 +112,6 @@ sub _score {
 
         $i++;
     }
-    undef $CACHE;
 
     for ( 0 .. $i ) {
         push( @order, log( $i - $_ + 1 ) );
@@ -131,28 +129,31 @@ sub _score {
       map {
 
         my $ratio_std =
-          ( ($ratio[$_] || 0) - ($ratio{mean} || 0) ) / ( $ratio{stddev} + 0.001 );
+          ( ( $ratio[$_] || 0 ) - ( $ratio{mean} || 0 ) ) /
+          ( $ratio{stddev} + 0.001 );
         my $depth_std =
-          ( ($depth[$_] || 0) - ($depth{mean} || 0) ) / ( $depth{stddev} + 0.001 );
+          ( ( $depth[$_] || 0 ) - ( $depth{mean} || 0 ) ) /
+          ( $depth{stddev} + 0.001 );
         my $order_std =
-          ( ($order[$_] || 0) - ($order{mean} || 0) ) / ( $order{stddev} + 0.001 );
+          ( ( $order[$_] || 0 ) - ( $order{mean} || 0 ) ) /
+          ( $order{stddev} + 0.001 );
 
         $data->[$_]->{score} = $ratio_std + $depth_std + $order_std;
         $_;
       } ( 0 .. $i );
     $data->[ $sorted[0] ]->{text} =~ s/ $//s;
 
-    $result->text($data->[ $sorted[0] ]->{text});
+    $result->text( $data->[ $sorted[0] ]->{text} );
 
-    if ($c->{element_flag}) {
+    if ( $c->{element_flag} ) {
         $result->root($root);
-        $result->element($data->[ $sorted[0] ]->{element});
+        $result->element( $data->[ $sorted[0] ]->{element} );
     }
 
     if ( $c->{enc_type} ) {
         $result->title( Encode::encode( $c->{enc_type}, $result->title ) );
-        $result->desc( Encode::encode( $c->{enc_type}, $result->desc ) );
-        $result->text( Encode::encode( $c->{enc_type}, $result->text ) );
+        $result->desc( Encode::encode( $c->{enc_type},  $result->desc ) );
+        $result->text( Encode::encode( $c->{enc_type},  $result->text ) );
     }
 
     return $result;
@@ -162,50 +163,29 @@ sub _walk_tree {
     my $self          = shift;
     my $node          = shift;
     my $node_hash_ref = shift;
-    my $CACHE         = shift;
 
-    my $data = $CACHE->{ $node };
-    if ( ! $data) {
-        $data = {
-            text => '',
-            a_length => 0,
-            short_string_length => 0,
-        };
-
-        if ( ref $node ) {
-            my $text_len = bytes::length( $node->as_text );
-            my $tag      = $node->tag;
-            $data->{text_length} = $text_len;
-
-            if ( $tag =~ /p|br|hr|tr|ul|li|ol|dl|dd/ ) {
-                $data->{text} = "\n";
-            }
-            if ( $tag =~ /a|dt|th|option/) {
-                $data->{a_length} += $text_len;
-            }
-
-            if ( $text_len < 20 ) {
-                $data->{short_string_length} += $text_len;
+    if ( ref $node ) {
+        if ( $node->tag =~ /p|br|hr|tr|ul|li|ol|dl|dd/ ) {
+            $node_hash_ref->{text} .= "\n";
+        }
+        for (qw/a option dt th/) {
+            if ( $node->tag eq $_ ) {
+                $node_hash_ref->{a_length} += bytes::length( $node->as_text );
             }
         }
-        else {
-            $data->{text} = $node . " ";
+        if ( bytes::length( $node->as_text ) < 20 ) {
+            $node_hash_ref->{short_string_length} +=
+              bytes::length( $node->as_text );
         }
-
-        $CACHE->{ $node } = $data;
+        $self->_walk_tree( $_, $node_hash_ref ) for $node->content_list();
     }
-
-    $node_hash_ref->{text}                .= $data->{text};
-    $node_hash_ref->{a_length}            += $data->{a_length};
-    $node_hash_ref->{short_string_length} += $data->{short_string_length};
-
-    if (ref $node) {
-        $self->_walk_tree( $_, $node_hash_ref, $CACHE )
-            for $node->content_list();
+    else {
+        $node_hash_ref->{text} .= $node . " ";
     }
-
 }
 
+
+
 1;
 
 __END__
